@@ -1,12 +1,11 @@
-# flake8: noqa
-__author__ = "Akio Taniguchi"
-__version__ = "0.6.2"
-
-
-# submodules
+# type: ignore
 from . import apps
 from . import arxiv
 from . import article
 from . import cli
 from . import consts
 from . import deepl
+
+
+# metadata
+__version__ = "0.6.4"
